==> nextcloud-27.1.11.tgz: nextcloud/apps/text/l10n/ko.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded or file size exceeds maximum of %s" : "파일이 업로드 되지 않았거나, 크기가 %s를 초과함",
    "text document" : "텍스트 문서",
    "New text file" : "새 텍스트 파일",
    "Create new text file" : "새 텍스트 파일 만들기",
    "This file cannot be displayed as download is disabled by the share" : "공유에서 다운로드가 비활성화 되었으므로 이 파일을 볼 수 없습니다.",
    "Text" : "텍스트",
    "Nextcloud Assistant" : "Nextcloud 어시스턴트",
    "Translate" : "번역:",
    "Use current version" : "최근 버젼을 사용하십시오.",
    "Use the saved version" : "이전 버전 사용하기",
    "Reload" : "새로 고침",
    "Reconnect" : "재연결",
    "This file is opened read-only as it is currently locked by {user}." : "이 파일은 {user}에 의해 잠겨 있으므로 읽기 전용으로 열립니다.",
    "Close outline view" : "개요 닫기",
    "Outline" : "개요",
    "Enter your name so other people can see who is editing" : "누가 수정하고 있는 지 다른 사람들이 알 수 있도록 이름을 입력하세요.",
    "Edit guest name" : "손님 이름 편집하기",
    "Guest" : "손님",
    "Save guest name" : "손님 이름 저장하기",
    "guest" : "손님",
    "Offline" : "오프라인",
    "Saving …" : "저장중 …",
    "Saved" : "저장됨",
    "The document has been changed outside of the editor. The changes cannot be applied." : "문서가 에디터 밖에서 변경되었습니다. 변경사항이 적용되지 않습니다.",
    "Unsaved changes" : "저장하지 않은 변경 사항",
    "Keyboard shortcuts" : "키보드 단축키",
    "Enter" : "Enter",
    "Backspace" : "백스페이스",
    "Shift" : "쉬프트",
    "Bold" : "굵게",
    "Bold text" : "굵은 텍스트",
    "Ctrl" : "Ctrl",
    "Italic" : "Italic체",
    "Italicized text" : "기울임꼴 텍스트",
    "Strikethrough" : "취소선",
    "Mistaken text" : "잘못된 텍스트",
    "Underline" : "밑줄",
    "Underlined text" : "밑줄 쳐진 텍스트",
    "Heading 1" : "제목 1",
    "Heading level 1" : "제목 단계 1",
    "Heading 6" : "제목 6",
    "Heading level 6" : "제목 단계 6",
    "Quoted text" : "인용문",
    "Link" : "링크",
    "Smart picker" : "스마트 피커",
    "Action" : "동작",
    "Undo" : "실행 취소",
    "Redo" : "다시 실행",
    "Edit link" : "링크 수정",
    "Save changes" : "설정 저장",
    "Cancel" : "취소",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "복사할 수 없습니다, 링크를 수동으로 복사하세요.",
    "Copy link to clipboard" : "링크를 클립보드에 복사",
    "Formatting help" : "서식 도움말",
    "Open the Smart Picker" : "스마트 피커 열기",
    "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
    "_%n word_::_%n words_" : ["%n개 단어"],
    "_%n char_::_%n chars_" : ["%n개 글자"],
    "Translate from" : "다음을 번역",
    "Select language" : "언어 선택",
    "to" : "에서",
    "Replace" : "바꾸기",
    "Insert" : "삽입",
    "Detect language" : "언어 감지",
    "Translation failed" : "번역 실패",
    "Edit" : "편집",
    "Copy code block" : "코드 블록 복사",
    "Source code" : "소스 코드",
    "Hide outline" : "개요 숨기기",
    "Show outline" : "개요 보이기",
    "Headings" : "제목",
    "Heading 2" : "제목 2",
    "Heading 3" : "제목 3",
    "Heading 4" : "제목 4",
    "Heading 5" : "제목 5",
    "Info" : "정보",
    "Success" : "성공",
    "Warning" : "경고",
    "Command" : "명령",
    "Control" : "제어:",
    "Formatting" : "서식",
    "Add folder description" : "폴더 설명 추가"
},
"nplurals=1; plural=0;");

==> nextcloud-28.0.14.tgz: nextcloud/apps/text/l10n/ko.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded or file size exceeds maximum of %s" : "파일이 업로드 되지 않았거나, 크기가 %s를 초과함",
    "text document" : "텍스트 문서",
    "New text file" : "새 텍스트 파일",
    "Create new text file" : "새 텍스트 파일 만들기",
    "This file cannot be displayed as download is disabled by the share" : "공유에서 다운로드가 비활성화 되었으므로 이 파일을 볼 수 없습니다.",
    "File not found" : "파일을 찾을 수 없음",
    "Text" : "텍스트",
    "Nextcloud Assistant" : "Nextcloud 어시스턴트",
    "Translate" : "번역:",
    "Use current version" : "최근 버젼을 사용하십시오.",
    "Use the saved version" : "이전 버전 사용하기",
    "Reload" : "새로 고침",
    "Reconnect" : "재연결",
    "This file is opened read-only as it is currently locked by {user}." : "이 파일은 {user}에 의해 잠겨 있으므로 읽기 전용으로 열립니다.",
    "Close outline view" : "개요 닫기",
    "Outline" : "개요",
    "Enter your name so other people can see who is editing" : "누가 수정하고 있는 지 다른 사람들이 알 수 있도록 이름을 입력하세요.",
    "Edit guest name" : "손님 이름 편집하기",
    "Guest" : "손님",
    "Save guest name" : "손님 이름 저장하기",
    "guest" : "손님",
    "Offline" : "오프라인",
    "Saving …" : "저장중 …",
    "Saved" : "저장됨",
    "The document has been changed outside of the editor. The changes cannot be applied." : "문서가 에디터 밖에서 변경되었습니다. 변경사항이 적용되지 않습니다.",
    "Unsaved changes" : "저장하지 않은 변경 사항",
    "Keyboard shortcuts" : "키보드 단축키",
    "Enter" : "Enter",
    "Backspace" : "백스페이스",
    "Shift" : "쉬프트",
    "Bold" : "굵게",
    "Bold text" : "굵은 텍스트",
    "Ctrl" : "Ctrl",
    "Italic" : "Italic체",
    "Italicized text" : "기울임꼴 텍스트",
    "Strikethrough" : "취소선",
    "Mistaken text" : "잘못된 텍스트",
    "Underline" : "밑줄",
    "Underlined text" : "밑줄 쳐진 텍스트",
    "Heading 1" : "제목 1",
    "Heading level 1" : "제목 단계 1",
    "Heading 6" : "제목 6",
    "Heading level 6" : "제목 단계 6",
    "Quoted text" : "인용문",
    "Link" : "링크",
    "Smart picker" : "스마트 피커",
    "Action" : "동작",
    "Undo" : "실행 취소",
    "Redo" : "다시 실행",
    "Edit link" : "링크 수정",
    "Save changes" : "설정 저장",
    "Cancel" : "취소",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "복사할 수 없습니다, 링크를 수동으로 복사하세요.",
    "Copy link to clipboard" : "링크를 클립보드에 복사",
    "Formatting help" : "서식 도움말",
    "Open the Smart Picker" : "스마트 피커 열기",
    "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
    "_%n word_::_%n words_" : ["%n개 단어"],
    "_%n char_::_%n chars_" : ["%n개 글자"],
    "Translate from" : "다음을 번역",
    "Select language" : "언어 선택",
    "to" : "에서",
    "Translate to" : "다음으로 번역",
    "Replace" : "바꾸기",
    "Insert" : "삽입",
    "Detect language" : "언어 감지",
    "Translation failed" : "번역 실패",
    "Edit" : "편집",
    "Copy code block" : "코드 블록 복사",
    "Source code" : "소스 코드",
    "Show folder description" : "폴더 설명 보이기",
    "Hide outline" : "개요 숨기기",
    "Show outline" : "개요 보이기",
    "Headings" : "제목",
    "Heading 2" : "제목 2",
    "Heading 3" : "제목 3",
    "Heading 4" : "제목 4",
    "Heading 5" : "제목 5",
    "Lists" : "목록",
    "Details" : "세부사항",
    "Command" : "명령",
    "Control" : "제어:",
    "Formatting" : "서식",
    "Add folder description" : "폴더 설명 추가",
    "Info" : "정보",
    "Success" : "성공",
    "Warning" : "경고"
},
"nplurals=1; plural=0;");
